<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="lo">
<context>
	<name>policy</name>
	<message>
		<location filename="com.deepin.pkexec.deepin-diskmanager!message" line="0"/>
		<source>Authentication is required to read disk information</source>
		<translation>ຕ້ອງການການຢືນຢັນເພື່ອອ່ານຂໍ້ມູນດິດ</translation>
	</message>
	<message>
		<location filename="com.deepin.pkexec.deepin-diskmanager!description" line="0"/>
		<source>Run Disk Manager Need Authentication</source>
		<translation>ການເຮັດວຽກກັບຜູ້ຈັດການດິສກ໌ຕ້ອງການການຢືນຢັນ</translation>
	</message>
</context>
</TS>
